"use strict";
import axios from "axios";
import { connectAsync, HttpClient, unpublishRecursively, } from "@artcom/mqtt-topping";
import { createLogger } from "@artcom/logger";
async function retrieveBootstrapData(url, timeout, retryDelay, logger, debugBootstrapData) {
    if (debugBootstrapData) {
        logger.info("Using debug bootstrap data", { ...debugBootstrapData });
        return debugBootstrapData;
    }
    if (!url) {
        const bootstrapData = {
            tcpBrokerUri: process.env.TCP_BROKER_URI,
            httpBrokerUri: process.env.HTTP_BROKER_URI,
            configServerUri: process.env.CONFIG_SERVER_URI,
            device: process.env.DEVICE,
        };
        logger.info("Using bootstrap data from environment", { ...bootstrapData });
        return bootstrapData;
    }
    logger.info("Querying bootstrap data", { url });
    while (true) {
        try {
            const { data } = await axios.get(url, { timeout });
            logger.info("Bootstrap data received", { ...data });
            return data;
        }
        catch (error) {
            if (error instanceof Error) {
                logger.error(`Query failed. Retrying in ${retryDelay}ms...`, {
                    error: error.message,
                });
            }
            else {
                logger.error("An unknown error occurred");
            }
            await delay(retryDelay);
        }
    }
}
function delay(time) {
    return new Promise((resolve) => setTimeout(resolve, time));
}
async function connectMqttClient(serviceId, tcpBrokerUri, device, onParseError, logger) {
    const clientId = createClientId(serviceId, device);
    logger.info("Connecting to Broker", { tcpBrokerUri, clientId });
    const mqttClient = await connectAsync(tcpBrokerUri, { clientId, onParseError });
    logger.info("Connected to Broker");
    mqttClient.on("close", () => {
        logger.error("Disconnected from Broker");
    });
    mqttClient.on("error", () => {
        logger.error("Error Connecting to Broker");
    });
    return mqttClient;
}
function createClientId(serviceId, device) {
    const uuid = Math.random().toString(16).substring(2, 10);
    if (device) {
        return `${serviceId}-${device}-${uuid}`;
    }
    else {
        return `${serviceId}-${uuid}`;
    }
}
function createQueryConfig(configServerUri) {
    return async (configPath, params = {}) => {
        const { version = "master", listFiles = false, includeCommitHash = false, parseJSON = true, } = params;
        const query = {
            url: `${configServerUri}/${version}/${configPath}?listFiles=${listFiles}`,
            responseType: parseJSON ? "json" : "text"
        };
        return axios(query).then((response) => includeCommitHash
            ? { data: response.data, commitHash: response.headers["git-commit-hash"] }
            : response.data);
    };
}
//# sourceMappingURL=main.mjs.map